@@ -250,8 +250,6 @@
 #ifndef CBF_H
 #define CBF_H
 
-// #include "hdf5.h"
-
 #ifdef __cplusplus
 
 extern "C" {
@@ -307,6 +305,11 @@ _CBF_STR(CBF_VERS_RELEASE) CBF_VERS_SUBRELEASE
 #include <limits.h>
 #include <stdio.h>
 
+// Large parts of the code assume ssize_t, which doesn't exist on windows
+#if defined(_MSC_VER)
+#include <BaseTsd.h>
+typedef SSIZE_T ssize_t;
+#endif
 
   /* Currently the cbf library assumes a 32-bit or larger integer */
 
